:mod:`routes.util` -- URL Generator and utility functions
=========================================================

.. automodule:: routes.util

Module Contents
---------------

.. autoexception:: RoutesException
.. autoexception:: MatchException
.. autoexception:: GenerationException
.. autoclass:: URLGenerator
    :members:
    :undoc-members:
.. autofunction:: url_for

.. autofunction:: _url_quote
.. autofunction:: _str_encode
.. autofunction:: _screenargs
.. autofunction:: _subdomain_check
